@@ -8,7 +8,7 @@ from enum import Enum
 
 import numpy as np
 
-from ctypes import c_int, c_void_p, c_char_p, c_long, c_bool, cdll
+from ctypes import c_int, c_void_p, c_char_p, c_long, c_bool, cdll, WinDLL
 from numpy.ctypeslib import as_ctypes
 
 supported_games_dict = {
@@ -34,7 +34,7 @@ def _load_cdll(path, name):
 
     try:
         if(sys.platform.startswith("win")):
-            return ctypes.WinDLL(library_path) 
+            return WinDLL(library_path) 
         else:
             return cdll.LoadLibrary(library_path)
     except Exception as ex:
